Index: /issm/trunk-jpl/src/c/objects/Options/Option.h
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/Option.h	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/Option.h	(revision 12534)
@@ -43,9 +43,9 @@
 		virtual int*  Size()=0;
 		virtual void  Get(int* pvalue)=0;
-		virtual void  Get(IssmPDouble* pvalue)=0;
+		virtual void  Get(IssmDouble* pvalue)=0;
 		virtual void  Get(bool* pvalue)=0;
 		virtual void  Get(char** pvalue)=0;
 		virtual void  Get(char*** ppvalue,int *pnumel)=0;
-		virtual void  Get(IssmPDouble** pvalue,int *pnumel)=0;
+		virtual void  Get(IssmDouble** pvalue,int *pnumel)=0;
 		virtual void  Get(Options** pvalue)=0;
 		virtual void  Get(Options*** ppvalue,int *pnumel)=0;
Index: /issm/trunk-jpl/src/c/objects/Options/OptionCell.h
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/OptionCell.h	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/OptionCell.h	(revision 12534)
@@ -40,9 +40,9 @@
 		int*  Size();
 		void  Get(int* pvalue){_error2_("An OptionCell object cannot return a int");};
-		void  Get(IssmPDouble* pvalue){_error2_("An OptionCell object cannot return a IssmPDouble");};
+		void  Get(IssmDouble* pvalue){_error2_("An OptionCell object cannot return a IssmDouble");};
 		void  Get(bool* pvalue){  _error2_("An OptionCell object cannot return a bool");};
 		void  Get(char** pvalue){ _error2_("An OptionCell object cannot return a string");};
 		void  Get(char*** ppvalue,int *pnumel){ _error2_("An OptionCell object cannot return a string vec");};
-		void  Get(IssmPDouble** pvalue,int *pnumel){ _error2_("An OptionCell object cannot return a IssmPDouble vec");};
+		void  Get(IssmDouble** pvalue,int *pnumel){ _error2_("An OptionCell object cannot return a IssmDouble vec");};
 		void  Get(Options** pvalue);
 		void  Get(Options*** ppvalue,int *pnumel){ _error2_("An OptionCell object cannot return an Options DataSet vec");};
Index: /issm/trunk-jpl/src/c/objects/Options/OptionChar.h
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/OptionChar.h	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/OptionChar.h	(revision 12534)
@@ -40,9 +40,9 @@
 		int*  Size();
 		void  Get(int* pvalue){_error2_("An OptionChar object cannot return a int");};
-		void  Get(IssmPDouble* pvalue){_error2_("An OptionChar object cannot return a IssmPDouble");};
+		void  Get(IssmDouble* pvalue){_error2_("An OptionChar object cannot return a IssmDouble");};
 		void  Get(bool* pvalue){  _error2_("An OptionChar object cannot return a bool");};
 		void  Get(char** pvalue);
 		void  Get(char*** ppvalue,int *pnumel);
-		void  Get(IssmPDouble** pvalue,int *pnumel){ _error2_("An OptionChar object cannot return a IssmPDouble vec");};
+		void  Get(IssmDouble** pvalue,int *pnumel){ _error2_("An OptionChar object cannot return a IssmDouble vec");};
 		void  Get(Options** pvalue){ _error2_("An OptionChar object cannot return an Options DataSet");};
 		void  Get(Options*** ppvalue,int *pnumel){ _error2_("An OptionChar object cannot return an Options DataSet vec");};
Index: /issm/trunk-jpl/src/c/objects/Options/OptionDouble.cpp
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/OptionDouble.cpp	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/OptionDouble.cpp	(revision 12534)
@@ -1,4 +1,4 @@
 /*!\file OptionDouble.cpp
- * \brief: implementation of the optionsIssmPDouble object
+ * \brief: implementation of the optionsIssmDouble object
  */
 
@@ -31,5 +31,5 @@
 OptionDouble::~OptionDouble(){
 
-	if (values) xDelete<IssmPDouble>(values);
+	if (values) xDelete<IssmDouble>(values);
 
 }
@@ -50,5 +50,5 @@
 		else {
 			StringFromSize(cstr,size,ndims);
-			if(flag) _pprintLine_("        values: " << cstr << " " << "IssmPDouble");
+			if(flag) _pprintLine_("        values: " << cstr << " " << "IssmDouble");
 		}
 	}
@@ -132,10 +132,10 @@
 }
 /*}}}*/
-/*FUNCTION OptionDouble::Get(IssmPDouble* pvalue) {{{*/
-void OptionDouble::Get(IssmPDouble* pvalue){
+/*FUNCTION OptionDouble::Get(IssmDouble* pvalue) {{{*/
+void OptionDouble::Get(IssmDouble* pvalue){
 
 	/*We should first check that the size is one*/
 	if(this->NumEl()!=1){
-		_error2_("option \"" << this->name << "\" has " << this->NumEl() << " elements and cannot return a single IssmPDouble");
+		_error2_("option \"" << this->name << "\" has " << this->NumEl() << " elements and cannot return a single IssmDouble");
 	}
 
@@ -144,14 +144,14 @@
 }
 /*}}}*/
-/*FUNCTION OptionDouble::Get(IssmPDouble** pvalue,int* numel) {{{*/
-void OptionDouble::Get(IssmPDouble** pvalue,int* numel){
+/*FUNCTION OptionDouble::Get(IssmDouble** pvalue,int* numel) {{{*/
+void OptionDouble::Get(IssmDouble** pvalue,int* numel){
 
 	/*We should first check that the size is at least one*/
 	if(this->NumEl()<=0){
-		_error2_("option \"" << this->name << "\" is empty and cannot return a IssmPDouble vector");
+		_error2_("option \"" << this->name << "\" is empty and cannot return a IssmDouble vector");
 	}
 
 	/*Copy vector*/
-	IssmPDouble* outvalue=xNew<IssmPDouble>(this->NumEl());
+	IssmDouble* outvalue=xNew<IssmDouble>(this->NumEl());
 	for(int i=0;i<this->NumEl();i++) outvalue[i]=this->values[i];
 
Index: /issm/trunk-jpl/src/c/objects/Options/OptionLogical.h
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/OptionLogical.h	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/OptionLogical.h	(revision 12534)
@@ -40,9 +40,9 @@
 		int*  Size();
 		void  Get(int* pvalue){_error2_("An OptionLogical object cannot return a int");};
-		void  Get(IssmPDouble* pvalue){_error2_("An OptionLogical object cannot return a IssmPDouble");};
+		void  Get(IssmDouble* pvalue){_error2_("An OptionLogical object cannot return a IssmDouble");};
 		void  Get(bool* pvalue);
 		void  Get(char** pvalue){ _error2_("An OptionLogical object cannot return a string");};
 		void  Get(char*** ppvalue,int *pnumel){ _error2_("An OptionLogical object cannot return a string vec");};
-		void  Get(IssmPDouble** pvalue,int *pnumel){ _error2_("An OptionLogical object cannot return a IssmPDouble vec");};
+		void  Get(IssmDouble** pvalue,int *pnumel){ _error2_("An OptionLogical object cannot return a IssmDouble vec");};
 		void  Get(Options** pvalue){ _error2_("An OptionLogical object cannot return an Options DataSet");};
 		void  Get(Options*** ppvalue,int *pnumel){ _error2_("An OptionLogical object cannot return an Options DataSet vec");};
Index: /issm/trunk-jpl/src/c/objects/Options/OptionStruct.h
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/OptionStruct.h	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/OptionStruct.h	(revision 12534)
@@ -40,9 +40,9 @@
 		int*  Size();
 		void  Get(int* pvalue){_error2_("An OptionStruct object cannot return a int");};
-		void  Get(IssmPDouble* pvalue){_error2_("An OptionStruct object cannot return a IssmPDouble");};
+		void  Get(IssmDouble* pvalue){_error2_("An OptionStruct object cannot return a IssmDouble");};
 		void  Get(bool* pvalue){  _error2_("An OptionStruct object cannot return a bool");};
 		void  Get(char** pvalue){ _error2_("An OptionStruct object cannot return a string");};
 		void  Get(char*** ppvalue,int *pnumel){ _error2_("An OptionStruct object cannot return a string vec");};
-		void  Get(IssmPDouble** pvalue,int *pnumel){ _error2_("An OptionStruct object cannot return a IssmPDouble vec");};
+		void  Get(IssmDouble** pvalue,int *pnumel){ _error2_("An OptionStruct object cannot return a IssmDouble vec");};
 		void  Get(Options** pvalue);
 		void  Get(Options*** ppvalue,int *pnumel);
Index: /issm/trunk-jpl/src/c/objects/Options/OptionUtilities.cpp
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/OptionUtilities.cpp	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/OptionUtilities.cpp	(revision 12534)
@@ -31,6 +31,6 @@
 	/*calculate the dimensions (being careful of integer division)  */
 	for (i=ndims-1; i>=0; i--) {
-		aprod=(int)(((IssmPDouble)aprod+0.5)/(IssmPDouble)size[i]);
-		dims[i]=(int)floor(((IssmPDouble)index+0.5)/(IssmPDouble)aprod);
+		aprod=(int)(((IssmDouble)aprod+0.5)/(IssmDouble)size[i]);
+		dims[i]=(int)floor(((IssmDouble)index+0.5)/(IssmDouble)aprod);
 		index-=dims[i]*aprod;
 	}
@@ -69,6 +69,6 @@
 	/*calculate the dimensions (being careful of integer division)  */
 	for (i=0; i<ndims; i++) {
-		aprod=(int)(((IssmPDouble)aprod+0.5)/(IssmPDouble)size[i]);
-		dims[i]=(int)floor(((IssmPDouble)index+0.5)/(IssmPDouble)aprod);
+		aprod=(int)(((IssmDouble)aprod+0.5)/(IssmDouble)size[i]);
+		dims[i]=(int)floor(((IssmDouble)index+0.5)/(IssmDouble)aprod);
 		index-=dims[i]*aprod;
 	}

Index: /issm/trunk-jpl/src/c/objects/Options/OptionDouble.h
===================================================================
--- /issm/trunk-jpl/src/c/objects/Options/OptionDouble.h	(revision 12533)
+++ /issm/trunk-jpl/src/c/objects/Options/OptionDouble.h	(revision 12534)
@@ -1,4 +1,4 @@
 /*! \file OptionDouble.h 
  *  \brief: header file for optionIssmPDouble object
  */
 
@@ -18,5 +18,5 @@
 	public:
 
-		IssmPDouble* values;
+		IssmDouble* values;
 
 		/*OptionDouble constructors, destructors {{{*/
@@ -40,9 +40,9 @@
 		int*  Size();
 		void  Get(int* pvalue);
-		void  Get(IssmPDouble* pvalue);
+		void  Get(IssmDouble* pvalue);
 		void  Get(bool* pvalue){  _error2_("An OptionDouble object cannot return a bool");};
 		void  Get(char** pvalue){ _error2_("An OptionDouble object cannot return a string");};
 		void  Get(char*** ppvalue,int *pnumel){ _error2_("An OptionDouble object cannot return a string vec");};
-		void  Get(IssmPDouble** pvalue,int* pnumel);
+		void  Get(IssmDouble** pvalue,int* pnumel);
 		void  Get(Options** pvalue){ _error2_("An OptionDouble object cannot return an Options DataSet");};
 		void  Get(Options*** ppvalue,int *pnumel){ _error2_("An OptionDouble object cannot return an Options DataSet vec");};
@@ -1,4 +1,4 @@
 /*! \file OptionDouble.h 
- *  \brief: header file for optionIssmPDouble object
+ *  \brief: header file for optionIssmDouble object
  */
 